==> alluxio-shaded-client-2.2.2-1-sources.jar: alluxio/shaded/client/io/netty/handler/codec/stomp/DefaultStompFrame.java <==
/*
 * Copyright 2014 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in alluxio.shaded.client.com.liance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.alluxio.shaded.client.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package alluxio.shaded.client.io.netty.handler.codec.stomp;

import alluxio.shaded.client.io.netty.buffer.ByteBuf;
import alluxio.shaded.client.io.netty.buffer.Unpooled;
import alluxio.shaded.client.io.netty.util.CharsetUtil;

/**
 * Default implementation of {@link StompFrame}.
 */
public class DefaultStompFrame extends DefaultStompHeadersSubframe implements StompFrame {

    private final ByteBuf content;

    public DefaultStompFrame(StompCommand alluxio.shaded.client.com.and) {
        this(alluxio.shaded.client.com.and, Unpooled.buffer(0));
    }

    public DefaultStompFrame(StompCommand alluxio.shaded.client.com.and, ByteBuf content) {
        this(alluxio.shaded.client.com.and, content, null);
    }

    DefaultStompFrame(StompCommand alluxio.shaded.client.com.and, ByteBuf content, DefaultStompHeaders headers) {
        super(alluxio.shaded.client.com.and, headers);

        if (content == null) {
            throw new NullPointerException("content");
        }

        this.content = content;
    }

    @Override
    public ByteBuf content() {
        return content;
    }

    @Override
    public StompFrame copy() {
        return replace(content.copy());
    }

    @Override
    public StompFrame duplicate() {
        return replace(content.duplicate());
    }

    @Override
    public StompFrame retainedDuplicate() {
        return replace(content.retainedDuplicate());
    }

    @Override
    public StompFrame replace(ByteBuf content) {
        return new DefaultStompFrame(alluxio.shaded.client.com.and, content, headers.copy());
    }

    @Override
    public int refCnt() {
        return content.refCnt();
    }

    @Override
    public StompFrame retain() {
        content.retain();
        return this;
    }

    @Override
    public StompFrame retain(int increment) {
        content.retain(increment);
        return this;
    }

    @Override
    public StompFrame touch() {
        content.touch();
        return this;
    }

    @Override
    public StompFrame touch(Object hint) {
        content.touch(hint);
        return this;
    }

    @Override
    public boolean release() {
        return content.release();
    }

    @Override
    public boolean release(int decrement) {
        return content.release(decrement);
    }

    @Override
    public String toString() {
        return "DefaultStompFrame{" +
            "alluxio.shaded.client.com.and=" + alluxio.shaded.client.com.and +
            ", headers=" + headers +
            ", content=" + content.toString(CharsetUtil.UTF_8) +
            '}';
    }
}

==> alluxio-shaded-client-2.8.1-sources.jar: alluxio/shaded/client/io/netty/handler/codec/stomp/DefaultStompFrame.java <==
/*
 * Copyright 2014 The Netty Project
 *
 * The Netty Project licenses this file to you under the Apache License,
 * version 2.0 (the "License"); you may not use this file except in alluxio.shaded.client.com.liance
 * with the License. You may obtain a copy of the License at:
 *
 *   http://www.apache.alluxio.shaded.client.org.licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package alluxio.shaded.client.io.netty.handler.codec.stomp;

import alluxio.shaded.client.io.netty.buffer.ByteBuf;
import alluxio.shaded.client.io.netty.buffer.Unpooled;
import alluxio.shaded.client.io.netty.util.CharsetUtil;
import alluxio.shaded.client.io.netty.util.internal.ObjectUtil;

/**
 * Default implementation of {@link StompFrame}.
 */
public class DefaultStompFrame extends DefaultStompHeadersSubframe implements StompFrame {

    private final ByteBuf content;

    public DefaultStompFrame(StompCommand alluxio.shaded.client.com.and) {
        this(alluxio.shaded.client.com.and, Unpooled.buffer(0));
    }

    public DefaultStompFrame(StompCommand alluxio.shaded.client.com.and, ByteBuf content) {
        this(alluxio.shaded.client.com.and, content, null);
    }

    DefaultStompFrame(StompCommand alluxio.shaded.client.com.and, ByteBuf content, DefaultStompHeaders headers) {
        super(alluxio.shaded.client.com.and, headers);
        this.content = ObjectUtil.checkNotNull(content, "content");
    }

    @Override
    public ByteBuf content() {
        return content;
    }

    @Override
    public StompFrame copy() {
        return replace(content.copy());
    }

    @Override
    public StompFrame duplicate() {
        return replace(content.duplicate());
    }

    @Override
    public StompFrame retainedDuplicate() {
        return replace(content.retainedDuplicate());
    }

    @Override
    public StompFrame replace(ByteBuf content) {
        return new DefaultStompFrame(alluxio.shaded.client.com.and, content, headers.copy());
    }

    @Override
    public int refCnt() {
        return content.refCnt();
    }

    @Override
    public StompFrame retain() {
        content.retain();
        return this;
    }

    @Override
    public StompFrame retain(int increment) {
        content.retain(increment);
        return this;
    }

    @Override
    public StompFrame touch() {
        content.touch();
        return this;
    }

    @Override
    public StompFrame touch(Object hint) {
        content.touch(hint);
        return this;
    }

    @Override
    public boolean release() {
        return content.release();
    }

    @Override
    public boolean release(int decrement) {
        return content.release(decrement);
    }

    @Override
    public String toString() {
        return "DefaultStompFrame{" +
            "alluxio.shaded.client.com.and=" + alluxio.shaded.client.com.and +
            ", headers=" + headers +
            ", content=" + content.toString(CharsetUtil.UTF_8) +
            '}';
    }
}
